﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace KioskDemo.Custom_Controls
{
    //Class to represent an entity that is shown on the map

    public class MapEntity : Panel
    {
        public string StoreName;
        public string StoreType;
        public string StoreLogoFilename;
        public int X, Y;


        public MapEntity(string name, string logo, string type, int x, int y):base()
        {
            this.StoreName = name;
            this.X = x;
            this.Y = y;
            this.StoreType = type;
            this.StoreLogoFilename = logo;
            // ../ means go up one directory layer. Look at file structure to see why from executable I need to move up three levels to find project folder with images in it
            this.BackgroundImage = Image.FromFile("../../../Images/Map/" + logo);
            this.BackgroundImageLayout = ImageLayout.Zoom;

            //Set up panel
            Size = new System.Drawing.Size(32, 32); //Small box for mouse over
            LocateItem();
            BorderStyle = BorderStyle.FixedSingle;  //for testing show border so we know we're hovering over it

            MouseClick += MapEntity_MouseClick; //Click to handle pressing on a touch screen
        }

        public void LocateItem()
        {
            if (Parent == null) return; //if not yet added to page this would otherwise crash
            //Note we use X and Y as a % from top left to bottom right
            //This means the true X position is X/100 * Width
            //Coordinates must be integer, but we must cast X and Y to float to divide by 100f (integer division of X/100 would only give 0 or 100 as the result)
            Location = new System.Drawing.Point((int)(Parent.Width * ((float)X / 100f)), (int)(Parent.Height * ((float)Y / 100f)));
        }

        private void MapEntity_MouseClick(object sender, MouseEventArgs e)
        {
            SingleStoreInfo s = new SingleStoreInfo(this);
            s.ShowDialog();
            //Use ShowDialog when you want to block the rest of the program until the window is shut
        }
    }
}
